[![Downloads](https://pepy.tech/badge/complex)](https://pepy.tech/project/complex)
[![Downloads](https://pepy.tech/badge/complex/month)](https://pepy.tech/project/complex/month)
[![Downloads](https://pepy.tech/badge/complex/week)](https://pepy.tech/project/complex/week)

# Complex
> Compute complex numbers operations such as addition, substraction, multiplication , division, modulus, conjugate and angle.

## Installation

OS X , Windows & Linux:

```sh
pip install complex
```
## Usage example
Use for complex number mathematics

```python
from complex import Complex
x = Complex(2,3)
y = Complex(4,5)
print(x+y, x-y, x*y, x/y, x.mod(), y.mod(), x.angle(), y.angle(), x.conjugate(), y.conjugate(), x.log(), y.log())
```

## Development setup
For local development setup

```sh
git clone https://github.com/deepak7376/complex
cd complex
pip install -r requirements.txt
```
## Meta
Deepak Yadav – [@imdeepak_dky](https://twitter.com/imdeepak_dky) – dky.united@gmail.com

Distributed under the MIT license. See ``LICENSE`` for more information.

[https://github.com/deepak7376/complex/blob/master/LICENSE](https://github.com/deepak7376)

## Contributing

1. Fork it (<https://github.com/deepak7376/complex/fork>)
2. Create your feature branch (`git checkout -b feature/fooBar`)
3. Commit your changes (`git commit -am 'Add some fooBar'`)
4. Push to the branch (`git push origin feature/fooBar`)
5. Create a new Pull Request

## References
None